// MyControllerForPlugins

#import <Cocoa/Cocoa.h>

@class MOEntry, MOCollection, MyCollectionTableView, MyWarningSheet;

@interface MyPluginManager : NSManagedObject 
- (void)addMenuItem:(NSMenuItem *)aMenuItem;
@end

// Application Controller 
@interface MyControllerForPlugins : NSObject
- (NSManagedObject *)selectedEntry;
- (NSArray *)arrangedEntries;
- (NSArray *)selectedEntries;
- (void)addEntriesWithAttributes:(NSArray *)entries;
- (NSString *)coverImagesPath;
- (MyPluginManager *)pluginManager;
- (MyCollectionTableView *)getCollections;
- (MyWarningSheet *)sharedWarningSheet;

- (BOOL)addEntry:(MOEntry *)anEntry toCollection:(MOCollection *)aCollection;
@end

@interface MOEntry : NSManagedObject 
- (NSString *)coverImagePath;
- (void)addLinkWithAttributtes:(NSDictionary *)attributes;
- (void)setCoverImage:(NSImage *)anImage;
@end

@interface MOLink : NSManagedObject 
- (void)deleteObject;
@end

@interface MyCollectionTableView : NSObject
- (MOCollection *)selectedCollection;
- (MOCollection *)borrowedCollection;
- (MOCollection *)wishlistCollection;
- (MOCollection *)libraryCollection;
- (NSArray *)allCollections;

// To select a collection use:
- (void)selectCollection:(MOCollection *)aCollection;

- (MOCollection *)createCollectionWithName:(NSString *)aName;
- (MOCollection *)createCollectionNamed:(NSString *)name withEntries:(NSSet *)aSet;
@end

//The method that the delgate implements to be told about search results
@interface NSObject (DelegateMethod) 
- (void)searchReturnedNumberOfResults:(int)numberOfResults sender:(id)sender;
@end


@protocol PediaPluginMandatory
+ (id)plugin;
@end


@interface NSObject (PediaPluginOptional)
- (void)setController:(MyControllerForPlugins *)aController;
- (NSArray *)menuCommandFor:(NSMutableArray *)entries;

- (void)searchFor:(NSDictionary *)searchDict sender:(id)sender;
- (NSArray *)resultsTitles;
- (NSDictionary *)resultNumber:(int)number;
@end


@interface MyWarningSheet : NSPanel

- (int)title:(NSString *)titleString text:(NSString *)text buttonOne:(NSString *)buttonOne buttonTwo:(NSString *)buttonTwo mask:(int)mask window:(NSWindow *)window;
- (int)cancelDeleteWarningTitle:(NSString *)titleString text:(NSString *)text mask:(int)mask window:(NSWindow *)window enableDeleteKey:(BOOL)enableDelete;


- (void)showProgressSheetWithTitle:(NSString *)aTitle subtitle:(NSString *)aSubtitle count:(int)incrementalCount;
- (void)closeProgressSheet;
- (void)setSubtitleForProgress:(NSString *)aString;
- (void)setTitleForProgress:(NSString *)aString;

- (void)increaseProgress;
- (NSProgressIndicator *)progressBar;
- (NSTextField *)progressSubtitle;
- (NSTextField *)progressTitle;
@end


//Extensions methods for NSString to help parse information
@interface NSString (NSStringExtensions)
//Returns the first string that occurs between the given strings or nil if none do
- (NSString *)stringBetween:(NSString *)startString and:(NSString *)endString;
	// Same as above but you can move the search to start at a given string, instead of the beginning
- (NSString *)stringBetween:(NSString *)startString and:(NSString *)endString startingFrom:(NSString *)primeString;
	// Return an array of all the strings that occur between the given strings or nil if none do
- (NSArray *)stringsBetween:(NSString *)startString and:(NSString *)endString;

- (BOOL)isNotEmpty;

// html cleaning
- (NSString *)stringByCleaningHTML;
- (NSString *)stringByReplacingHTMLEncoding;
- (NSString *)stringByRemovingLeadingAndTrailingSpaces;

@end
